// SPDX-FileCopyrightText: 2022 Matteo Settenvini <matteo.settenvini@montecristosoftware.eu>
// SPDX-License-Identifier: GPL-3.0-or-later

use {
    serde::{Deserialize, Serialize},
    std::net::IpAddr,
    zbus::{dbus_proxy, Result},
};

#[dbus_proxy(
    default_service = "com.endlessm.ParentalControls",
    interface = "com.endlessm.ParentalControls.Dns",
    default_path = "/com/endlessm/ParentalControls/Dns",
    gen_blocking = false
)]
trait MalcontentDns {
    fn get_restrictions(&self, uid: u32) -> Result<Restrictions>;
}

#[derive(Clone, Debug, PartialEq, Eq, Serialize, Deserialize, zvariant::Type)]
pub struct Restriction {
    pub ip: IpAddr,
    pub hostname: String,
}

pub type Restrictions = Vec<Restriction>;
